==> istio-model-v1beta1-6.1.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/ConnectionPoolSettingsTCPSettingsTcpKeepaliveFluentImpl.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ConnectionPoolSettingsTCPSettingsTcpKeepaliveFluentImpl<A extends ConnectionPoolSettingsTCPSettingsTcpKeepaliveFluent<A>> extends BaseFluent<A> implements ConnectionPoolSettingsTCPSettingsTcpKeepaliveFluent<A>{
  public ConnectionPoolSettingsTCPSettingsTcpKeepaliveFluentImpl() {
  }
  public ConnectionPoolSettingsTCPSettingsTcpKeepaliveFluentImpl(ConnectionPoolSettingsTCPSettingsTcpKeepalive instance) {
    this.withInterval(instance.getInterval()); 
    this.withProbes(instance.getProbes()); 
    this.withTime(instance.getTime()); 
  }
  private String interval;
  private Integer probes;
  private String time;
  public String getInterval() {
    return this.interval;
  }
  public A withInterval(String interval) {
    this.interval=interval; return (A) this;
  }
  public Boolean hasInterval() {
    return this.interval != null;
  }
  public Integer getProbes() {
    return this.probes;
  }
  public A withProbes(Integer probes) {
    this.probes=probes; return (A) this;
  }
  public Boolean hasProbes() {
    return this.probes != null;
  }
  public String getTime() {
    return this.time;
  }
  public A withTime(String time) {
    this.time=time; return (A) this;
  }
  public Boolean hasTime() {
    return this.time != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ConnectionPoolSettingsTCPSettingsTcpKeepaliveFluentImpl that = (ConnectionPoolSettingsTCPSettingsTcpKeepaliveFluentImpl) o;
    if (interval != null ? !interval.equals(that.interval) :that.interval != null) return false;
    if (probes != null ? !probes.equals(that.probes) :that.probes != null) return false;
    if (time != null ? !time.equals(that.time) :that.time != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(interval,  probes,  time,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (interval != null) { sb.append("interval:"); sb.append(interval + ","); }
    if (probes != null) { sb.append("probes:"); sb.append(probes + ","); }
    if (time != null) { sb.append("time:"); sb.append(time); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> istio-model-v1beta1-6.7.1-sources.jar: io/fabric8/istio/api/networking/v1beta1/ConnectionPoolSettingsTCPSettingsTcpKeepaliveFluentImpl.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ConnectionPoolSettingsTCPSettingsTcpKeepaliveFluentImpl<A extends ConnectionPoolSettingsTCPSettingsTcpKeepaliveFluent<A>> extends BaseFluent<A> implements ConnectionPoolSettingsTCPSettingsTcpKeepaliveFluent<A>{
  public ConnectionPoolSettingsTCPSettingsTcpKeepaliveFluentImpl() {
  }
  public ConnectionPoolSettingsTCPSettingsTcpKeepaliveFluentImpl(ConnectionPoolSettingsTCPSettingsTcpKeepalive instance) {
    if (instance != null) {
      this.withInterval(instance.getInterval());
      this.withProbes(instance.getProbes());
      this.withTime(instance.getTime());
    }
  }
  private String interval;
  private Integer probes;
  private String time;
  public String getInterval() {
    return this.interval;
  }
  public A withInterval(String interval) {
    this.interval=interval; return (A) this;
  }
  public Boolean hasInterval() {
    return this.interval != null;
  }
  public Integer getProbes() {
    return this.probes;
  }
  public A withProbes(Integer probes) {
    this.probes=probes; return (A) this;
  }
  public Boolean hasProbes() {
    return this.probes != null;
  }
  public String getTime() {
    return this.time;
  }
  public A withTime(String time) {
    this.time=time; return (A) this;
  }
  public Boolean hasTime() {
    return this.time != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ConnectionPoolSettingsTCPSettingsTcpKeepaliveFluentImpl that = (ConnectionPoolSettingsTCPSettingsTcpKeepaliveFluentImpl) o;
    if (!java.util.Objects.equals(interval, that.interval)) return false;

    if (!java.util.Objects.equals(probes, that.probes)) return false;

    if (!java.util.Objects.equals(time, that.time)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(interval,  probes,  time,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (interval != null) { sb.append("interval:"); sb.append(interval + ","); }
    if (probes != null) { sb.append("probes:"); sb.append(probes + ","); }
    if (time != null) { sb.append("time:"); sb.append(time); }
    sb.append("}");
    return sb.toString();
  }
  
}
